import { HttpHeaderType, ApiParamType, HttpRequest, ProxyConfig, RequestConfig, HttpResponse } from './types';
import { InterceptorManager, Tenant } from '../common';
import { AuthToken } from '../auth';
/**
 * Api配置类型
 */
export interface ApiConfig {
    /**
     * api请求基础路径，如：https://dinosdev.cn/api
     */
    baseUrl: string;
    /**
     * 接口请求超时时间(毫秒)，默认：-1，表示不设置超时
     */
    requestTimeout?: number;
    /**
     * 接口成功返回状态码，默认：0
     */
    successCode?: number | number[];
    /**
     * 需要重新登录的状态码，默认：630
     */
    needLoginCode?: number | number[];
    /**
     * 获取租户信息函数
     * @returns null表示不需要租户信息
     */
    tenant?: () => Promise<Tenant> | Tenant;
    /**
     * 获取登录凭证函数
     * @returns null表示不需要登录凭证
     */
    authToken?: () => Promise<AuthToken> | AuthToken;
    /**
     * 自动登录函数
     * @returns 自动登录成功返回true，否则返回false
     */
    autoLogin?: () => Promise<boolean>;
    /**
     * 登录过期回调函数，用于自动登录失败后的处理
     */
    onLoginExpired?: () => void;
    /**
     * 接口请求默认的headers
     * @default {}
     */
    defaultHeaders?: HttpHeaderType;
    /**
     * 接口请求默认的url参数
     * @default {}
     */
    defaultParams?: ApiParamType;
    /**
     * 是否开启代理
     * @default false
     */
    proxy?: ProxyConfig | false;
}
/**
 * 默认的Api配置
 */
export declare const defaultApiConfig: ApiConfig;
/**
 * Request Provider函数类型
 */
export type RequestProvider = (config: ApiConfig) => HttpRequest;
/**
 * Api选项类型
 */
export interface ApiOptions {
    /**
     * 请求提供函数
     */
    requestProvider: RequestProvider;
    /**
     * api配置
     */
    config: ApiConfig;
}
/**
 * ApiService接口
 */
export interface ApiService {
    /**
     * 服务名称
     */
    readonly serviceName: string;
    /**
     * Api配置
     */
    apiConfig: ApiConfig;
    /**
     * 拦截器管理器
     */
    readonly interceptors: {
        readonly request: InterceptorManager<RequestConfig, {
            apiService: ApiService;
        }>;
        readonly response: InterceptorManager<HttpResponse, {
            requestConfig: RequestConfig;
            apiService: ApiService;
        }>;
    };
    /**
     * Callback function to handle API errors.
     */
    onApiError?: (error: {
        status: number;
        code: number;
        message: string;
    }) => void;
    /**
     * 请求函数
     */
    request: HttpRequest;
}
/**
 * 配置API
 * @param options Api选项
 * @param service 服务名称
 * @returns ApiService
 */
export declare const setupApi: (options: ApiOptions, service?: string) => ApiService;
/**
 * 获取服务Api
 * @param service 服务名称
 * @returns ApiService
 * @throws Error 如果服务未配置，则抛出错误
 */
export declare const useApi: (service?: string) => ApiService;
